items_table

Macro items_table 

macro_rules! items_table {
    ($items:expr, $name:expr, $id:expr) => { ... };
}
Build a table with the exact border / separator style you posted and return the rendered string.

Parameters

  • $items - A table builder that implements the Table trait (e.g. Vec<Vec<...>>.into_table(), items.into_table(), …).
  • $name - The name that should be stored in EpochError::TableStringConversionError.
  • $id - The id that should be stored in EpochError::TableStringConversionError.